@@ -1,4 +1,4 @@
-import pytest
+import pytest  # noqa
 
 from trava.fit_predictor import FitPredictorSteps
 
@@ -16,12 +16,12 @@ def test_addition(mocker):
     first_final_steps = gen_steps(n=1)
     second_final_steps = gen_steps(n=1)
 
-    first = FitPredictorSteps(raw_model_steps=first_raw_model_steps,
-                              config_steps=first_config_steps,
-                              final_steps=first_final_steps)
-    second = FitPredictorSteps(raw_model_steps=second_raw_model_steps,
-                               config_steps=second_config_steps,
-                               final_steps=second_final_steps)
+    first = FitPredictorSteps(
+        raw_model_steps=first_raw_model_steps, config_steps=first_config_steps, final_steps=first_final_steps
+    )
+    second = FitPredictorSteps(
+        raw_model_steps=second_raw_model_steps, config_steps=second_config_steps, final_steps=second_final_steps
+    )
 
     result = first + second
 
