@@ -9,6 +9,7 @@ class SplitResultHandler(ABC):
     """
     Can be used to modify SplitResult ( e.g. apply resampling )
     """
+
     @abstractmethod
     def handle(self, split_result: SplitResult) -> SplitResult:
         pass
@@ -18,13 +19,16 @@ class DataSplitConfig:
     """
     Data class containing all the data needed to make a split.
     """
-    def __init__(self,
-                 split_logic: SplitLogic,
-                 target_col_name: str,
-                 test_size: float,
-                 valid_size: float = 0.0,
-                 split_result_handlers: Optional[List[SplitResultHandler]] = None,
-                 ignore_cols: Optional[List[str]] = None):
+
+    def __init__(
+        self,
+        split_logic: SplitLogic,
+        target_col_name: str,
+        test_size: float,
+        valid_size: float = 0.0,
+        split_result_handlers: Optional[List[SplitResultHandler]] = None,
+        ignore_cols: Optional[List[str]] = None,
+    ):
         self.split_logic = split_logic
         self.target_col_name = target_col_name
         self.test_size = test_size
